@@ -2,8 +2,11 @@
 import importlib
 
 from django import template
+from django.core.urlresolvers import resolve, Resolver404
 from django.db.models.fields import FieldDoesNotExist
 
+from django_libs import utils
+
 
 register = template.Library()
 
@@ -43,6 +46,11 @@ def get_verbose(obj, field_name=""):
     return ""
 
 
+@register.assignment_tag
+def get_profile_for(user):
+    return utils.get_profile(user)
+
+
 class LoadContextNode(template.Node):
     def __init__(self, fqn):
         self.fqn = fqn
@@ -88,11 +96,16 @@ def navactive(request, url, exact=0):
       ``request.path``.
 
     """
-    if exact:
-        if url == request.path:
+    try:
+        if url == resolve(request.path).view_name:
             return "active"
         return ""
+    except Resolver404:
+        if exact:
+            if url == request.path:
+                return "active"
+            return ""
 
-    if url in request.path:
-        return "active"
-    return ""
+        if url in request.path:
+            return "active"
+        return ""
